@@ -420,6 +420,8 @@ static SymTabRec NVKnownChipsets[] =
   { 0x10DE05E1, "GeForce GTX 280" },
   { 0x10DE05E2, "GeForce GTX 260" },
   { 0x10DE05E3, "GeForce GTX 285" },
+  { 0x10DE05E6, "GeForce GTX 275" },
+  { 0x10DE05EB, "GeForce GTX 295" },
   { 0x10DE05F9, "Quadro CX" },
   { 0x10DE05FD, "Quadro FX 5800" },
   { 0x10DE05FE, "Quadro FX 4800" },
@@ -430,8 +432,10 @@ static SymTabRec NVKnownChipsets[] =
   { 0x10DE0604, "GeForce 9800 GX2" },
   { 0x10DE0605, "GeForce 9800 GT" },
   { 0x10DE0606, "GeForce 8800 GS" },
+  { 0x10DE0607, "GeForce GTS 240" },
   { 0x10DE0608, "GeForce 9800M GTX" },
   { 0x10DE0609, "GeForce 8800M GTS" },
+  { 0x10DE060A, "GeForce GTX 280M" },
   { 0x10DE060B, "GeForce 9800M GT" },
   { 0x10DE060C, "GeForce 8800M GTX" },
   { 0x10DE060D, "GeForce 8800 GS" },
@@ -442,9 +446,12 @@ static SymTabRec NVKnownChipsets[] =
   { 0x10DE0614, "GeForce 9800 GT" },
   { 0x10DE0615, "GeForce GTS 250" },
   { 0x10DE0617, "GeForce 9800M GTX" },
+  { 0x10DE0618, "GeForce GTX 260M" },
   { 0x10DE061A, "Quadro FX 3700" },
   { 0x10DE061C, "Quadro FX 3600M" },
+  { 0x10DE061D, "Quadro FX 2800M" },
   { 0x10DE061E, "Quadro FX 3700M" },
+  { 0x10DE061F, "Quadro FX 3800M" },
   { 0x10DE0622, "GeForce 9600 GT" },
   { 0x10DE0623, "GeForce 9600 GS" },
   { 0x10DE0625, "GeForce 9600 GSO 512" },
@@ -459,6 +466,7 @@ static SymTabRec NVKnownChipsets[] =
   { 0x10DE0640, "GeForce 9500 GT" },
   { 0x10DE0641, "GeForce 9400 GT" },
   { 0x10DE0643, "GeForce 9500 GT" },
+  { 0x10DE0644, "GeForce 9500 GS" },
   { 0x10DE0646, "GeForce GT 120" },
   { 0x10DE0647, "GeForce 9600M GT" },
   { 0x10DE0648, "GeForce 9600M GS" },
@@ -466,9 +474,11 @@ static SymTabRec NVKnownChipsets[] =
   { 0x10DE064A, "GeForce 9700M GT" },
   { 0x10DE064B, "GeForce 9500M G" },
   { 0x10DE064C, "GeForce 9650M GT" },
+  { 0x10DE0652, "GeForce GT 130M" },
   { 0x10DE0656, "GeForce 9500 GT" },
   { 0x10DE0658, "Quadro FX 380" },
   { 0x10DE0659, "Quadro FX 580" },
+  { 0x10DE065A, "Quadro FX 1700M" },
   { 0x10DE065C, "Quadro FX 770M" },
   { 0x10DE06E0, "GeForce 9300 GE" },
   { 0x10DE06E1, "GeForce 9300 GS" },
@@ -479,10 +489,26 @@ static SymTabRec NVKnownChipsets[] =
   { 0x10DE06E9, "GeForce 9300M GS" },
   { 0x10DE06EA, "Quadro NVS 150M" },
   { 0x10DE06EB, "Quadro NVS 160M" },
+  { 0x10DE06EC, "GeForce G 105M" },
+  { 0x10DE06EF, "GeForce G 103M" },
   { 0x10DE06F8, "Quadro NVS 420" },
   { 0x10DE06F9, "Quadro FX 370 LP" },
   { 0x10DE06FA, "Quadro NVS 450" },
   { 0x10DE06FD, "Quadro NVS 295" },
+  { 0x10DE0A20, "GeForce GT 220" },
+  { 0x10DE0A23, "GeForce 210" },
+  { 0x10DE0A2A, "GeForce GT 230M" },
+  { 0x10DE0A34, "GeForce GT 240M" },
+  { 0x10DE0A60, "GeForce G210" },
+  { 0x10DE0A62, "GeForce 205" },
+  { 0x10DE0A63, "GeForce 310" },
+  { 0x10DE0A65, "GeForce 210" },
+  { 0x10DE0A66, "GeForce 310" },
+  { 0x10DE0A74, "GeForce G210M" },
+  { 0x10DE0A78, "Quadro FX 380 LP" },
+  { 0x10DE0CA3, "GeForce GT 240" },
+  { 0x10DE0CA8, "GeForce GTS 260M" },
+  { 0x10DE0CA9, "GeForce GTS 250M" },
 
   {-1, NULL}
 };
@@ -727,9 +753,12 @@ NVIsG80(int chipType)
         case 0x0650:
         case 0x06e0:
         case 0x06f0:
+        case 0x0a20:
+        case 0x0a30:
         case 0x0a60:
         case 0x0a70:
         case 0x0ca0:
+        case 0x0cb0:
             return TRUE;
     }
 
